# pyCOMPASS>_
pyCOMPASS is a Python interface to COMPASS, the gene expression compendia GraphQL endpoint



## Documentation

The full documentation is hosted on [ReadTheDocs](https://pycompass.readthedocs.io)


## License

This project is licensed under the GPLv3 License - see the [LICENSE](LICENSE) file for details